#!/bin/bash

set -e -u

# Script to create the binary distributions from a build directory produced
# by buildall.sh
#
# Usage: mkccclientdist.sh <build directory> <target suffix> [<destination directory>]

scriptdir=`dirname $0`
scriptdir=`cd "${scriptdir}" && pwd`

if test $# -lt 2; then
    echo "Usage: mkccclientdist.sh <build directory> <target suffix> [<destination directory>]"
    exit 1
fi

builddir="${1}"
installdir="${builddir}/install"
targetsuffix="${2}"
destdir="${3:-}"
if test -z "${destdir}"; then
    destdir=`pwd`
fi

tmpdir=`mktemp -d`
trap "rm -rf $tmpdir" EXIT

# mkdist <dll prefix> <includedir> <libprefix> <pcfile> <m4file>
mkdist()
{
    local buildsubdir="${1}"
    local dllprefix="${2}"
    local includedir="${3}"
    local libprefix="${4}"
    local pcfile="${5:-}"
    local m4file="${6:-}"

    rm -rf "${tmpdir}"

    if test -f "${installdir}/bin/${dllprefix}"*.dll; then
        mkdir -p "${tmpdir}/bin"
        cp -a "${installdir}/bin/${dllprefix}"*.dll "${tmpdir}/bin"
    fi

    local includeparentdir=`dirname "${includedir}"`

    mkdir -p "${tmpdir}/include/${includeparentdir}"
    cp -a "${installdir}/include/${includedir}" "${tmpdir}/include/${includeparentdir}"

    if test "${pcfile}"; then
        mkdir -p "${tmpdir}/lib/pkgconfig"
    else
        mkdir -p "${tmpdir}/lib"
    fi
    cp -a "${installdir}/lib/${libprefix}"* "${tmpdir}/lib"
    if test "${pcfile}"; then
        cp -a "${installdir}/lib/pkgconfig/${pcfile}.pc" "${tmpdir}/lib/pkgconfig"
    fi

    if test "${m4file}"; then
        mkdir -p "${tmpdir}/share/aclocal"
        cp -a "${installdir}/share/aclocal/${m4file}.m4" "${tmpdir}/share/aclocal"
    fi

    local version=`cat "${builddir}/${buildsubdir}/config.status" | grep 'S\["PACKAGE_VERSION"\]=' | sed 's:S\["PACKAGE_VERSION"]="\([^"]*\)":\1:'`
    local targetfile="${destdir}/${buildsubdir}-${version}-${targetsuffix}"
    rm -f "${targetfile}"

    cd "${tmpdir}"

    case "${targetfile}" in
        *.zip)
            zip -q -r "${targetfile}" *
            ;;
        *.tar.gz)
            tar czf "${targetfile}" *
            ;;
        *.tar.bz2)
            tar cjf "${targetfile}" *
            ;;
    esac
}

#---------------------------------------

echo "Packing VSCPL"
mkdist vscpl libvscpl hu/varadiistvan/scpl libvscpl vscpl vscpl

echo "Packing XPLCOMMON"
mkdist xplcommon libxplcommon hu/varadiistvan/xplcommon libxplcommon libxplcommon ""

echo "Packing XPLRA"
mkdist xplra libxplra hu/varadiistvan/xplra libxplra "" ""

echo "Done."
